#include "hotlistdialog.h"
#include <qpushbutton.h>
#include <qlistbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qdir.h>
#include <qfile.h>
#include <qinputdialog.h>
#include <kseparator.h>
#include <kiconloader.h>
#include <ksimpleconfig.h>
#include <klocale.h>
#include <kbuttonbox.h>
#include <kfiledialog.h>
#include <kmessagebox.h>


HotListDialog::HotListDialog(QWidget *parent, const char *name)
    : QDialog(parent, name, true)
{
    modified = false;
    QGridLayout *layout = new QGridLayout(this, 1, 1, 5, 5);

    //QLabel *lbl = new QLabel(i18n("<B>HotList Group Editor:</B>"), this);
    //layout->addMultiCellWidget(lbl, 1, 1, 0, 1);
    QLabel *lbl = new QLabel(i18n("HotList groups are a PixiePlus feature to provide easy access\n\
to folders used for images. The Mosfet Image Loader for Konqueror\n\
can check these groups for duplicate image filenames. To create a \n\
Hotlist group simply press the \"Add\" button, select a folder, \n\
then select a symbolic name to use in the menus. This folder will\n\
then be checked for duplicates when loading images."), this);
    layout->addMultiCellWidget(lbl, 2, 2, 0, 1);

    listBox = new QListBox(this);
    load();
    connect(listBox, SIGNAL(highlighted(int)), this,
            SLOT(slotItemHighlighted(int)));
    layout->addMultiCellWidget(listBox, 3, 5, 0, 0);

    QPushButton *addBtn = new QPushButton(i18n("Add..."), this);
    connect(addBtn, SIGNAL(clicked()), this, SLOT(slotAdd()));
    layout->addWidget(addBtn, 3, 1);

    removeBtn = new QPushButton(i18n("Remove..."), this);
    connect(removeBtn, SIGNAL(clicked()), this, SLOT(slotRemove()));
    layout->addWidget(removeBtn, 4, 1);

    layout->addMultiCellWidget(new KSeparator(Qt::Horizontal, this),
                               6, 6, 0, 1);

    KButtonBox *bbox = new KButtonBox(this);
    bbox->addStretch(1);
    okayBtn = bbox->addButton(i18n("OK"));
    connect(okayBtn, SIGNAL(clicked()), this, SLOT(slotAccept()));
    connect(bbox->addButton(i18n("Cancel")), SIGNAL(clicked()), this,
            SLOT(reject()));
    layout->addMultiCellWidget(bbox, 7, 7, 0, 1);

    layout->setColStretch(0, 1);
    layout->setRowStretch(5, 1);

    okayBtn->setEnabled(false);
    removeBtn->setEnabled(false);
    setCaption(i18n("Edit PixiePlus HotList Groups"));
}

void HotListDialog::slotAdd()
{
    QString pathStr = KFileDialog::getExistingDirectory(QString::null,
                                                        this,
                                                        i18n("Select a folder to add"));
    if(!pathStr.isEmpty()){
        QFileInfo fi(pathStr);
        if(!fi.exists() || !fi.isDir()){
            KMessageBox::sorry(this, i18n("Hotlist addition on invalid path!"));
            return;
        }
        QString labelStr = QInputDialog::getText(i18n("HotList Name"),
                                                 i18n("Please enter a symbolic name to use when\n\
accessing this directory from the hotlist."),
                                                 QLineEdit::Normal,
                                                 QDir(pathStr).dirName(),
                                                 0, this);
        if(!labelStr)
            return;
        listBox->insertItem(BarIcon("folder", KIcon::SizeMedium), labelStr);
        listBox->setCurrentItem(listBox->count()-1);
        listBox->ensureCurrentVisible();

        paths.append(pathStr);
        modified = true;
        okayBtn->setEnabled(true);
        removeBtn->setEnabled(true);
    }
}

void HotListDialog::slotRemove()
{
    int id = listBox->currentItem();
    if(id == 0){
        KMessageBox::sorry(this, i18n("Cannot remove Home folder!"));
        removeBtn->setEnabled(false);
    }
    else if(id == -1){
        KMessageBox::sorry(this, i18n("Please select an item first!"));
        removeBtn->setEnabled(false);
    }
    else{
        int i=0;
        for(QStringList::Iterator it = paths.begin(); it != paths.end();
            ++i, ++it){
            if(i == id){
                qWarning("Removing path: %s", (const char *)
                         QFile::encodeName(*it));
                paths.remove(it);
                listBox->removeItem(i);
                removeBtn->setEnabled(false);
                okayBtn->setEnabled(true);
                modified = true;
                return;
            }
        }
    }
}

void HotListDialog::slotItemHighlighted(int id)
{
    if(id == 0)
        removeBtn->setEnabled(false);
    else
        removeBtn->setEnabled(true);
}

void HotListDialog::slotAccept()
{
    save();
    accept();
}

void HotListDialog::load()
{
    KConfig *config = new KSimpleConfig("pixierc");
    config->setGroup("Thumbnails");

    listBox->insertItem(BarIcon("kfm_home", KIcon::SizeMedium),
                        i18n("Home"), 0);
    paths.append(QDir::homeDirPath());

    QStringList nameList = config->readListEntry("Names");
    QStringList pathList = config->readListEntry("Paths");

    if(!nameList.count() || ! pathList.count())
        return;
    int i=1;
    for(QStringList::Iterator it = nameList.begin(); it != nameList.end();
        ++it, ++i){
        listBox->insertItem(BarIcon("folder", KIcon::SizeMedium),
                            (*it), i);
    }
    for(QStringList::Iterator it = pathList.begin(); it != pathList.end(); ++it)
        paths.append((*it));

    delete config;
}

void HotListDialog::save()
{
    KConfig *config = new KSimpleConfig("pixierc");
    config->setGroup("Thumbnails");
    QStringList pathList(paths);
    pathList.remove(pathList.begin()); // remove home entry

    QStringList nameList;
    for(unsigned int i=1; i < listBox->count(); ++i)
        nameList.append(listBox->item(i)->text());

    qWarning("Names:");
    for(QStringList::Iterator it=nameList.begin(); it != nameList.end(); ++it)
        qWarning("%s", (*it).latin1());
    qWarning("Paths:");
    for(QStringList::Iterator it=pathList.begin(); it != pathList.end(); ++it)
        qWarning("%s", (*it).latin1());

    config->writeEntry("Names", nameList);
    config->writeEntry("Paths", pathList);
    config->sync();

    delete config;
}


