#ifndef __MOSFETIMAGE_PART_H
#define __MOSFETIMAGE_PART_H

#include <kparts/browserextension.h>
#include <kparts/factory.h>
#include <qguardedptr.h>
#include <qsignalmapper.h>
#include "imageviewer.h"

class KInstance;
class KAction;
class MosfetImageBrowserExtension;
class QLabel;
class QProcess;
class KAboutData;

class MosfetImagePart: public KParts::ReadOnlyPart
{
    Q_OBJECT
    friend class MosfetImageBrowserExtension;
public:
    MosfetImagePart(QWidget *parentWidget, const char *widgetName,
                    QObject *parent, const char *name,
                    const QStringList &args = QStringList());
    virtual ~MosfetImagePart();
    ImageView *imageWidget() const {return(widget);}
    virtual bool openURL(const KURL &url);
    virtual bool openFile(){return(false);}
    virtual bool closeURL();
    static KAboutData* createAboutData();
protected:
    void guiActivateEvent(KParts::GUIActivateEvent *);
protected slots:
    void slotViewerStarted(KIO::Job *);
    void slotViewerCanceled(const QString &);
    void slotViewerCompleted();
    void slotViewerPopup(const QPoint &globalPos);
    void slotTitle(const QString &);
    void slotStatus(const QString &);

    void slotCopyLocation();
    void slotCopyFilename();
    void slotSaveAs();
    void slotHotList(int id);
    void slotBackground();
    void slotConfigureHotlist();

    void slotFinishedCopy();
    void slotWallpaperProcExited();
private:
    QGuardedPtr<ImageView> widget;
    MosfetImageBrowserExtension *extension;
    bool inBackground;
    QProcess *wallpaperProc;
};

class MosfetImageBrowserExtension : public KParts::BrowserExtension
{
    Q_OBJECT
public:
    MosfetImageBrowserExtension(MosfetImagePart *parent);
    virtual ~MosfetImageBrowserExtension();
    int xOffset();
    int yOffset();
protected slots:
    void print();
    void reparseConfiguration();
protected:
    MosfetImagePart *imagePart;

};


#endif


